@@ -1,53 +1,56 @@
+from concurrent.futures import ThreadPoolExecutor
 from contextlib import suppress
+from sqlite3 import OperationalError
+from sys import argv as sys_argv
+from sys import stdout
 from typing import Any
+
 from snakypy.helpers import FG, printer
 from snakypy.helpers.ansi import NONE
-from snakypy.zshpower.prompt.sections.took import Took
-from tomlkit.exceptions import NonExistentKey, UnexpectedCharError
-from sqlite3 import OperationalError
 from snakypy.helpers.decorators import only_linux
-from snakypy.zshpower.prompt.sections.gulp import Gulp
-from snakypy.zshpower.prompt.sections.jump_line import JumpLine
-from snakypy.zshpower.config import package
-from snakypy.zshpower.database.dao import DAO
-from snakypy.zshpower.config.config import content as config_content
-from snakypy.zshpower.utils.shift import create_config
-from snakypy.helpers.path import create as snakypy_path_create
 from snakypy.helpers.files import read_file
+from snakypy.helpers.path import create as create_path
 from tomlkit import parse as toml_parse
-from concurrent.futures import ThreadPoolExecutor
-from snakypy.zshpower.prompt.sections.directory import Directory
-from snakypy.zshpower.prompt.sections.git import Git
-from snakypy.zshpower.prompt.sections.hostname import Hostname
-from snakypy.zshpower.prompt.sections.command import Command
-from snakypy.zshpower.prompt.sections.username import Username
-from snakypy.zshpower.prompt.sections.package import Package
-from snakypy.zshpower.prompt.sections.docker import Docker
-from snakypy.zshpower.prompt.sections.nodejs import NodeJs
-from snakypy.zshpower.prompt.sections.python import Python, Virtualenv
-from snakypy.zshpower.prompt.sections.rust import Rust
-from snakypy.zshpower.prompt.sections.golang import Golang
-from snakypy.zshpower.prompt.sections.php import Php
-from snakypy.zshpower.prompt.sections.elixir import Elixir
-from snakypy.zshpower.prompt.sections.julia import Julia
-from snakypy.zshpower.prompt.sections.scala import Scala
-from snakypy.zshpower.prompt.sections.ruby import Ruby
-from snakypy.zshpower.prompt.sections.dotnet import Dotnet
-from snakypy.zshpower.prompt.sections.java import Java
-from snakypy.zshpower.prompt.sections.dart import Dart
-from snakypy.zshpower.prompt.sections.zig import Zig
-from snakypy.zshpower.prompt.sections.vagrant import Vagrant
-from snakypy.zshpower.prompt.sections.ocaml import Ocaml
-from snakypy.zshpower.prompt.sections.nim import Nim
-from snakypy.zshpower.prompt.sections.kotlin import Kotlin
-from snakypy.zshpower.prompt.sections.helm import Helm
-from snakypy.zshpower.prompt.sections.erlang import Erlang
-from snakypy.zshpower.prompt.sections.deno import Deno
-from snakypy.zshpower.prompt.sections.crystal import Crystal
+from tomlkit.exceptions import NonExistentKey, UnexpectedCharError
+
+from snakypy.zshpower import __info__
+from snakypy.zshpower.config.config import content as config_content
+from snakypy.zshpower.database.dao import DAO
 from snakypy.zshpower.prompt.sections.cmake import CMake
+from snakypy.zshpower.prompt.sections.command import Command
+from snakypy.zshpower.prompt.sections.crystal import Crystal
+from snakypy.zshpower.prompt.sections.dart import Dart
+from snakypy.zshpower.prompt.sections.deno import Deno
+from snakypy.zshpower.prompt.sections.directory import Directory
+from snakypy.zshpower.prompt.sections.docker import Docker
+from snakypy.zshpower.prompt.sections.dotnet import Dotnet
+from snakypy.zshpower.prompt.sections.elixir import Elixir
+from snakypy.zshpower.prompt.sections.erlang import Erlang
+from snakypy.zshpower.prompt.sections.git import Git
+from snakypy.zshpower.prompt.sections.golang import Golang
+from snakypy.zshpower.prompt.sections.gulp import Gulp
+from snakypy.zshpower.prompt.sections.helm import Helm
+from snakypy.zshpower.prompt.sections.hostname import Hostname
+from snakypy.zshpower.prompt.sections.java import Java
+from snakypy.zshpower.prompt.sections.julia import Julia
+from snakypy.zshpower.prompt.sections.jump_line import JumpLine
+from snakypy.zshpower.prompt.sections.kotlin import Kotlin
+from snakypy.zshpower.prompt.sections.nim import Nim
+from snakypy.zshpower.prompt.sections.nodejs import NodeJs
+from snakypy.zshpower.prompt.sections.ocaml import Ocaml
+from snakypy.zshpower.prompt.sections.package import Package
 from snakypy.zshpower.prompt.sections.perl import Perl
+from snakypy.zshpower.prompt.sections.php import Php
+from snakypy.zshpower.prompt.sections.python import Python, Virtualenv
+from snakypy.zshpower.prompt.sections.ruby import Ruby
+from snakypy.zshpower.prompt.sections.rust import Rust
+from snakypy.zshpower.prompt.sections.scala import Scala
 from snakypy.zshpower.prompt.sections.timer import Timer
-from sys import argv as sys_argv, stdout
+from snakypy.zshpower.prompt.sections.took import Took
+from snakypy.zshpower.prompt.sections.username import Username
+from snakypy.zshpower.prompt.sections.vagrant import Vagrant
+from snakypy.zshpower.prompt.sections.zig import Zig
+from snakypy.zshpower.utils.shift import create_config
 
 # ## Test timer ## #
 # from snakypy.helpers.decorators import runtime
@@ -61,15 +64,13 @@ class Draw(DAO):
 
     def get_config(self) -> dict:
         try:
-            read_conf = read_file(self.config_file)
-            parsed = dict(toml_parse(read_conf))
+            parsed = dict(toml_parse(read_file(self.config_file)))
             return parsed
 
         except (FileNotFoundError, NonExistentKey):
-            snakypy_path_create(self.zshpower_home)
+            create_path(self.zshpower_home)
             create_config(config_content, self.config_file)
-            read_conf = read_file(self.config_file)
-            parsed = dict(toml_parse(read_conf))
+            parsed = dict(toml_parse(read_file(self.config_file)))
             return parsed
 
     def get_register(self):
@@ -81,7 +82,7 @@ class Draw(DAO):
             return data
         except (KeyError, OperationalError):
             printer(
-                f'{package.info["name"]} Error: Database corrupted. Run command: '
+                f'{__info__["name"]} Error: Database corrupted. Run command: '
                 f'"zshpower reset --db" to restore.\n>> ',
                 foreground=FG().ERROR,
             )
@@ -159,14 +160,14 @@ class Draw(DAO):
 
         except (NonExistentKey, UnexpectedCharError, ValueError):
             print(
-                f"{FG().ERROR}{package.info['name']} Error: Key error in "
+                f"{FG().ERROR}{__info__['name']} Error: Key error in "
                 f"the configuration file.\n> {NONE}"
             )
             raise
         except KeyError:
             raise KeyError(
-                f"{FG().ERROR}{package.info['name']} Error: Database records are missing "
-                f"or corrupted. Run the command to correct: \"{package.info['executable']} reset --db\".\n>> "
+                f"{FG().ERROR}{__info__['name']} Error: Database records are missing "
+                f"or corrupted. Run the command to correct: \"{__info__['executable']} reset --db\".\n>> "
             )
         return ""
 
@@ -176,7 +177,7 @@ class Draw(DAO):
             return f"{timer}"
         except NonExistentKey:
             return (
-                f"{FG().ERROR}>>> {package.info['name']} Error: Key error in "
+                f"{FG().ERROR}>>> {__info__['name']} Error: Key error in "
                 f"the configuration file.\n > "
             )
 
