@@ -1,8 +1,8 @@
-from snakypy.helpers.catches import shell
-from snakypy.helpers import FG, printer
-from snakypy.helpers.catches import whoami
 from subprocess import call as subprocess_call
 
+from snakypy.helpers import FG, printer
+from snakypy.helpers.catches import shell, whoami
+
 
 def reload_zsh() -> None:
     subprocess_call("exec zsh", shell=True)
